==> owncloud-10.0.7.tgz: owncloud/apps/federatedfilesharing/l10n/cs_CZ.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Propojené sdílení",
    "Invalid Federated Cloud ID" : "Neplatné sdružené cloud ID",
    "Sharing %s failed, because this item is already shared with %s" : "Sdílení položky %s selhalo, protože položka již je s uživatelem %s sdílena",
    "Not allowed to create a federated share with the same user" : "Není povoleno vytvořit propojené sdílení s tím samým uživatelem",
    "File is already shared with %s" : "Soubor je již sdílen s %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Sdílení %s selhalo, %s se nepodařilo nalézt, server pravděpodobně právě není dostupný.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Obdrželi jste \"/%3$s\" jako vzdálené sdílení od %1$s (zastupuje %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Obdrželi jste \"/%3$s\" jako vzdálené sdílení od %1$s",
    "Accept" : "Přijmout",
    "Decline" : "Zamítnout",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Sdílej se mnou pomocí mého #ownCloud sdruženého cloud ID, více na %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Sdílej se mnou pomocí mého #ownCloud sdruženého cloud ID",
    "Federated Cloud Sharing" : "Propojené cloudové sdílení",
    "Open documentation" : "Otevřít dokumentaci",
    "Allow users on this server to send shares to other servers" : "Povolit uživatelům z tohoto serveru zasílat sdílení na jiné servery",
    "Allow users on this server to receive shares from other servers" : "Povolit uživatelům na tomto serveru přijímat sdílení z jiných serverů",
    "Federated Cloud" : "Sdružený cloud",
    "Your Federated Cloud ID:" : "Vaše sdružené cloud ID:",
    "Share it:" : "Sdílet:",
    "Add to your website" : "Přidat na svou webovou stránku",
    "Share with me via ownCloud" : "Sdíleno se mnou přes ownCloud",
    "HTML Code:" : "HTML kód:"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/cs_CZ.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Propojené sdílení",
    "Invalid Federated Cloud ID" : "Neplatné sdružené cloud ID",
    "Sharing %s failed, because this item is already shared with %s" : "Sdílení položky %s selhalo, protože položka již je s uživatelem %s sdílena",
    "Not allowed to create a federated share with the same user" : "Není povoleno vytvořit propojené sdílení s tím samým uživatelem",
    "File is already shared with %s" : "Soubor je již sdílen s %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Sdílení %s selhalo, %s se nepodařilo nalézt, server pravděpodobně právě není dostupný.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Obdrželi jste \"/%3$s\" jako vzdálené sdílení od %1$s (zastupuje %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Obdrželi jste \"/%3$s\" jako vzdálené sdílení od %1$s",
    "Accept" : "Přijmout",
    "Decline" : "Zamítnout",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Sdílej se mnou pomocí mého #ownCloud sdruženého cloud ID, více na %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Sdílej se mnou pomocí mého #ownCloud sdruženého cloud ID",
    "Federated Cloud Sharing" : "Propojené cloudové sdílení",
    "Open documentation" : "Otevřít dokumentaci",
    "Allow users on this server to send shares to other servers" : "Povolit uživatelům z tohoto serveru zasílat sdílení na jiné servery",
    "Allow users on this server to receive shares from other servers" : "Povolit uživatelům na tomto serveru přijímat sdílení z jiných serverů",
    "Federated Cloud" : "Sdružený cloud",
    "Your Federated Cloud ID:" : "Vaše sdružené cloud ID:",
    "Share it:" : "Sdílet:",
    "Add to your website" : "Přidat na svou webovou stránku",
    "Share with me via ownCloud" : "Sdíleno se mnou přes ownCloud",
    "HTML Code:" : "HTML kód:",
    "Add to your ownCloud" : "Přidat do svého ownCloudu"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
